@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use List::Util qw{ max min };
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use constant ARRAY_REF	=> ref [];
 
@@ -754,7 +754,8 @@ L<Game::Life|Game::Life>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Game-Life-Faster/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -762,7 +763,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2019-2020 by Thomas R. Wyant, III
+Copyright (C) 2019-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
